#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 call-stack
version:              0.4.0
visibility:           public
id:                   call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
key:                  call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/call-stack#readme
synopsis:             Use GHC call-stacks in a backward compatible way
category:             Data
abi:                  d58c3ac3b3b6d3475b439cb5c98b7194
exposed:              True
exposed-modules:      Data.CallStack
hidden-modules:       Data.SrcLoc Paths_call_stack
import-dirs:          /usr/lib/ghc-9.6.6/site-local/call-stack-0.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/call-stack-0.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/call-stack-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-call-stack
hs-libraries:         HScall-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-call-stack/html/call-stack.haddock
haddock-html:         /usr/share/doc/haskell-call-stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

